from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class EmailUsersConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'rps_milea_users'
    verbose_name = _("User and Groups")
    menu_icon = "ti ti-users-group"
